@@ -44,20 +44,20 @@ class DataLevel(Enum):
 class Institution(Enum):
     """Institution name"""
 
-    AIND = "AIND"
     AIBS = "AIBS"
+    AIND = "AIND"
+    CU = "Columbia University"
     HUST = "HUST"
     NYU = "NYU"
-    CU = "Columbia University"
 
 
 class Group(Enum):
     """Data collection group name"""
 
-    EPHYS = "ephys"
-    OPHYS = "ophys"
-    MSMA = "MSMA"
     BEHAVIOR = "behavior"
+    EPHYS = "ephys"
+    MSMA = "MSMA"
+    OPHYS = "ophys"
 
 
 class Modality(Enum):
@@ -65,10 +65,13 @@ class Modality(Enum):
 
     ECEPHYS = "ecephys"
     EXASPIM = "ExASPIM"
-    SMARTSPIM = "SmartSPIM"
-    MESOSPIM = "mesoSPIM"
-    OPHYS = "ophys"
+    FIP = "FIP"
     FMOST = "fMOST"
+    HSFP = "HSFP"
+    MESOSPIM = "mesoSPIM"
+    MRI = "MRI"
+    OPHYS = "ophys"
+    SMARTSPIM = "SmartSPIM"
 
 
 def datetime_to_name_string(d, t):
@@ -127,9 +130,10 @@ class DataDescription(AindCoreModel):
         title="Institution",
     )
     ror_id: Optional[str] = Field(
-        None, 
+        None,
         title="ROR ID",
-        description="Institution ID from the Research Organization Registry",)
+        description="Institution ID from the Research Organization Registry",
+    )
 
     funding_source: List[Funding] = Field(
         ...,
@@ -172,13 +176,9 @@ class DataDescription(AindCoreModel):
         ...,
         regex=DataRegex.NO_UNDERSCORES.value,
         description="Unique identifier for the subject of data acquisition",
-        title="Subject ID"
-    )
-    data_summary: Optional[str] = Field(
-        None,
-        title="Data summary",
-        description="Semantic summary of experimental goal"
+        title="Subject ID",
     )
+    data_summary: Optional[str] = Field(None, title="Data summary", description="Semantic summary of experimental goal")
 
     def __init__(self, label=None, **kwargs):
         """Construct a generic DataDescription"""
